==> IO-K8s-1.000.tar.gz: IO-K8s-1.000/lib/IO/K8s/Api/Autoscaling/V2/ObjectMetricSource.pm <==
package IO::K8s::Api::Autoscaling::V2::ObjectMetricSource;
# ABSTRACT: ObjectMetricSource indicates how to scale on a metric describing a kubernetes object (for example, hits-per-second on an Ingress object).
our $VERSION = '1.000';
use IO::K8s::Resource;

k8s describedObject => 'Autoscaling::V2::CrossVersionObjectReference', 'required';


k8s metric => 'Autoscaling::V2::MetricIdentifier', 'required';


k8s target => 'Autoscaling::V2::MetricTarget', 'required';


1;

__END__

=pod

=encoding UTF-8

=head1 NAME

IO::K8s::Api::Autoscaling::V2::ObjectMetricSource - ObjectMetricSource indicates how to scale on a metric describing a kubernetes object (for example, hits-per-second on an Ingress object).

=head1 VERSION

version 1.000

=head2 describedObject

describedObject specifies the descriptions of a object,such as kind,name apiVersion

=head2 metric

metric identifies the target metric by name and selector

=head2 target

target specifies the target value for the given metric

=head1 SUPPORT

=head2 Issues

Please report bugs and feature requests on GitHub at
L<https://github.com/pplu/io-k8s-p5/issues>.

=head2 IRC

Join C<#kubernetes> on C<irc.perl.org> or message Getty directly.

=head1 CONTRIBUTING

Contributions are welcome! Please fork the repository and submit a pull request.

=head1 AUTHORS

=over 4

=item *

Torsten Raudssus <torsten@raudssus.de>

=item *

Jose Luis Martinez <jlmartinez@capside.com> (original author, inactive)

=back

=head1 COPYRIGHT AND LICENSE

This software is Copyright (c) 2018 by CAPSiDE.

This is free software, licensed under:

  The Apache License, Version 2.0, January 2004

=cut

==> IO-K8s-1.001.tar.gz: IO-K8s-1.001/lib/IO/K8s/Api/Autoscaling/V2/ObjectMetricSource.pm <==
package IO::K8s::Api::Autoscaling::V2::ObjectMetricSource;
# ABSTRACT: ObjectMetricSource indicates how to scale on a metric describing a kubernetes object (for example, hits-per-second on an Ingress object).
our $VERSION = '1.001';
use IO::K8s::Resource;

k8s describedObject => 'Autoscaling::V2::CrossVersionObjectReference', 'required';


k8s metric => 'Autoscaling::V2::MetricIdentifier', 'required';


k8s target => 'Autoscaling::V2::MetricTarget', 'required';


1;

__END__

=pod

=encoding UTF-8

=head1 NAME

IO::K8s::Api::Autoscaling::V2::ObjectMetricSource - ObjectMetricSource indicates how to scale on a metric describing a kubernetes object (for example, hits-per-second on an Ingress object).

=head1 VERSION

version 1.001

=head2 describedObject

describedObject specifies the descriptions of a object,such as kind,name apiVersion

=head2 metric

metric identifies the target metric by name and selector

=head2 target

target specifies the target value for the given metric

=head1 SUPPORT

=head2 Issues

Please report bugs and feature requests on GitHub at
L<https://github.com/pplu/io-k8s-p5/issues>.

=head2 IRC

Join C<#kubernetes> on C<irc.perl.org> or message Getty directly.

=head1 CONTRIBUTING

Contributions are welcome! Please fork the repository and submit a pull request.

=head1 AUTHORS

=over 4

=item *

Torsten Raudssus <torsten@raudssus.de>

=item *

Jose Luis Martinez <jlmartin@cpan.org> (original author, inactive)

=back

=head1 COPYRIGHT AND LICENSE

This software is Copyright (c) 2018 by Jose Luis Martinez.

This is free software, licensed under:

  The Apache License, Version 2.0, January 2004

=cut
